==> af-common-socket-2.11.12-sources.jar: com/af/v4/system/common/socket/core/server/modbus/ModBusServer.java <==
package com.af.v4.system.common.socket.core.server.modbus;

import com.af.v4.system.common.core.enums.OSType;
import com.af.v4.system.common.core.service.ApplicationService;
import com.af.v4.system.common.socket.core.channel.impl.ModbusTCPChannelHandler;
import com.af.v4.system.common.socket.core.decoder.ModbusRequestDecoder;
import com.af.v4.system.common.socket.core.encoder.ModbusResponseEncoder;
import com.af.v4.system.common.socket.core.server.SocketServer;
import io.netty.bootstrap.AbstractBootstrap;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.ChannelInitializer;
import io.netty.channel.ChannelOption;
import io.netty.channel.EventLoopGroup;
import io.netty.channel.ServerChannel;
import io.netty.channel.epoll.EpollEventLoopGroup;
import io.netty.channel.epoll.EpollServerSocketChannel;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.ServerSocketChannel;
import io.netty.channel.socket.SocketChannel;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import jakarta.annotation.PreDestroy;

/**
 * ModBus服务端
 */
public class ModBusServer extends SocketServer<ServerBootstrap, ServerChannel> {
    private EventLoopGroup bossGroup;
    private EventLoopGroup workerGroup;

    @Override
    protected AbstractBootstrap<ServerBootstrap, ServerChannel> initBootstrap() {
        Class<? extends ServerSocketChannel> channelClass;
        if (ApplicationService.getOSType() == OSType.LINUX) {
            bossGroup = new EpollEventLoopGroup();
            workerGroup = new EpollEventLoopGroup();
            channelClass = EpollServerSocketChannel.class;
        } else {
            bossGroup = new NioEventLoopGroup();
            workerGroup = new NioEventLoopGroup();
            channelClass = NioServerSocketChannel.class;
        }
        return new ServerBootstrap()
                .group(bossGroup, workerGroup)
                .channel(channelClass)
                .childHandler(new ChannelInitializer<SocketChannel>() {
                    @Override
                    protected void initChannel(SocketChannel ch) {
                        ch.pipeline().addLast(new ModbusRequestDecoder());
                        ch.pipeline().addLast(new ModbusResponseEncoder());
                        ch.pipeline().addLast(new ModbusTCPChannelHandler());
                    }
                })
                // tcp缓冲区
                .option(ChannelOption.SO_BACKLOG, 128)
                // 将网络数据积累到一定的数量后,服务器端才发送出去,会造成一定的延迟。希望服务是低延迟的,建议将TCP_NODELAY设置为true
                .childOption(ChannelOption.TCP_NODELAY, false)
                // 保持长连接
                .childOption(ChannelOption.SO_KEEPALIVE, true);
    }

    /**
     * 销毁
     */
    @PreDestroy
    public void destroy() {
        workerGroup.shutdownGracefully();
        bossGroup.shutdownGracefully();
    }
}

==> af-common-socket-2.13.49-sources.jar: com/af/v4/system/common/socket/core/server/modbus/ModBusServer.java <==
package com.af.v4.system.common.socket.core.server.modbus;

import com.af.v4.system.common.core.enums.OSType;
import com.af.v4.system.common.core.service.ApplicationService;
import com.af.v4.system.common.socket.SocketServerManager;
import com.af.v4.system.common.socket.config.SocketConfigItem;
import com.af.v4.system.common.socket.core.channel.impl.ModbusTCPChannelHandler;
import com.af.v4.system.common.socket.core.decoder.ModbusRequestDecoder;
import com.af.v4.system.common.socket.core.encoder.ModbusResponseEncoder;
import com.af.v4.system.common.socket.core.server.SocketServer;
import io.netty.bootstrap.AbstractBootstrap;
import io.netty.bootstrap.ServerBootstrap;
import io.netty.channel.ChannelInitializer;
import io.netty.channel.ChannelOption;
import io.netty.channel.EventLoopGroup;
import io.netty.channel.ServerChannel;
import io.netty.channel.epoll.EpollEventLoopGroup;
import io.netty.channel.epoll.EpollServerSocketChannel;
import io.netty.channel.nio.NioEventLoopGroup;
import io.netty.channel.socket.ServerSocketChannel;
import io.netty.channel.socket.SocketChannel;
import io.netty.channel.socket.nio.NioServerSocketChannel;
import io.netty.handler.logging.LogLevel;
import io.netty.handler.logging.LoggingHandler;
import io.netty.handler.timeout.IdleStateHandler;
import jakarta.annotation.PreDestroy;

/**
 * ModBus服务端
 */
public class ModBusServer extends SocketServer<ServerBootstrap, ServerChannel> {
    private EventLoopGroup bossGroup;
    private EventLoopGroup workerGroup;

    @Override
    protected AbstractBootstrap<ServerBootstrap, ServerChannel> initBootstrap() {
        Class<? extends ServerSocketChannel> channelClass;
        if (ApplicationService.getOSType() == OSType.LINUX) {
            bossGroup = new EpollEventLoopGroup();
            workerGroup = new EpollEventLoopGroup();
            channelClass = EpollServerSocketChannel.class;
        } else {
            bossGroup = new NioEventLoopGroup();
            workerGroup = new NioEventLoopGroup();
            channelClass = NioServerSocketChannel.class;
        }
        return new ServerBootstrap()
                .group(bossGroup, workerGroup)
                .channel(channelClass)
                .option(ChannelOption.SO_REUSEADDR, true)
                .childHandler(new ChannelInitializer<SocketChannel>() {
                    @Override
                    protected void initChannel(SocketChannel ch) {
                        Integer idle = SocketServerManager.getConfigItemByChannel(ch).map(SocketConfigItem::getIdleSeconds).orElse(60);
                        Boolean debug = SocketServerManager.getConfigItemByChannel(ch).map(SocketConfigItem::getDebugLogging).orElse(false);
                        if (LOGGER.isDebugEnabled() || debug) {
                            ch.pipeline().addFirst(new LoggingHandler(LogLevel.DEBUG));
                        }
                        ch.pipeline().addLast(new IdleStateHandler(0, 0, idle <= 0 ? 60 : idle));
                        ch.pipeline().addLast(new ModbusRequestDecoder());
                        ch.pipeline().addLast(new ModbusResponseEncoder());
                        ch.pipeline().addLast(new ModbusTCPChannelHandler());
                    }
                })
                // tcp缓冲区
                .option(ChannelOption.SO_BACKLOG, 128)
                // 将网络数据积累到一定的数量后,服务器端才发送出去,会造成一定的延迟。希望服务是低延迟的,建议将TCP_NODELAY设置为true
                .childOption(ChannelOption.TCP_NODELAY, true)
                // 保持长连接
                .childOption(ChannelOption.SO_KEEPALIVE, true)
                .childOption(ChannelOption.SO_REUSEADDR, true);
    }

    /**
     * 销毁
     */
    @PreDestroy
    public void destroy() {
        closeAllChannels();
        workerGroup.shutdownGracefully();
        bossGroup.shutdownGracefully();
    }
}
